pub struct CreateOAuthProviderOptions {Show 18 fields
pub name: CompactString,
pub description: Option<CompactString>,
pub enabled: bool,
pub login_only: bool,
pub link_viewable: bool,
pub user_manageable: bool,
pub basic_auth: bool,
pub client_id: CompactString,
pub client_secret: CompactString,
pub auth_url: String,
pub token_url: String,
pub info_url: String,
pub scopes: Vec<CompactString>,
pub identifier_path: String,
pub email_path: Option<String>,
pub username_path: Option<String>,
pub name_first_path: Option<String>,
pub name_last_path: Option<String>,
}Fields
name: CompactStringdescription: Option<CompactString>enabled: boollogin_only: boollink_viewable: booluser_manageable: boolbasic_auth: boolclient_id: CompactStringclient_secret: CompactStringauth_url: Stringtoken_url: Stringinfo_url: Stringscopes: Vec<CompactString>identifier_path: Stringemail_path: Option<String>username_path: Option<String>name_first_path: Option<String>name_last_path: Option<String>Trait Implementations
Sourceimpl ComposeSchema for CreateOAuthProviderOptions
impl ComposeSchema for CreateOAuthProviderOptions
Sourceimpl<'de> Deserialize<'de> for CreateOAuthProviderOptions
impl<'de> Deserialize<'de> for CreateOAuthProviderOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateOAuthProviderOptions
impl ToSchema for CreateOAuthProviderOptions
Sourceimpl Validate for CreateOAuthProviderOptions
impl Validate for CreateOAuthProviderOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateOAuthProviderOptions
impl RefUnwindSafe for CreateOAuthProviderOptions
impl Send for CreateOAuthProviderOptions
impl Sync for CreateOAuthProviderOptions
impl Unpin for CreateOAuthProviderOptions
impl UnwindSafe for CreateOAuthProviderOptions